@@ -28,8 +28,6 @@ typedef struct _pxConfigFile pxConfigFile;
 
 pxConfigFile *px_config_file_new         (char *filename);
 bool          px_config_file_is_stale    (pxConfigFile *self);
-char        **px_config_file_get_sections(pxConfigFile *self);
-char        **px_config_file_get_keys    (pxConfigFile *self, char *section);
 char         *px_config_file_get_value   (pxConfigFile *self, char *section, char *key);
 void          px_config_file_free        (pxConfigFile *self);
 
